UnityAdsLoadError enum
Error category of load errors
Values
- initializeFailed → const UnityAdsLoadError
-
Error related to SDK not initialized
- internalError → const UnityAdsLoadError
-
Error related to environment or internal services
- invalidArgument → const UnityAdsLoadError
-
Error related to invalid arguments
- noFill → const UnityAdsLoadError
-
Error related to there being no ads available
- timeout → const UnityAdsLoadError
-
Error related to there being no ads available
- unknown → const UnityAdsLoadError
-
Unknown error
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UnityAdsLoadError> - A constant List of the values in this enum, in order of their declaration.